@@ -25,6 +25,9 @@ import (
 	"github.com/apache/incubator-answer/internal/repo/activity_common"
 	"github.com/apache/incubator-answer/internal/repo/answer"
 	"github.com/apache/incubator-answer/internal/repo/auth"
+	"github.com/apache/incubator-answer/internal/repo/badge"
+	"github.com/apache/incubator-answer/internal/repo/badge_award"
+	"github.com/apache/incubator-answer/internal/repo/badge_group"
 	"github.com/apache/incubator-answer/internal/repo/captcha"
 	"github.com/apache/incubator-answer/internal/repo/collection"
 	"github.com/apache/incubator-answer/internal/repo/comment"
@@ -100,4 +103,8 @@ var ProviderSetRepo = wire.NewSet(
 	limit.NewRateLimitRepo,
 	plugin_config.NewPluginUserConfigRepo,
 	review.NewReviewRepo,
+	badge.NewBadgeRepo,
+	badge.NewEventRuleRepo,
+	badge_group.NewBadgeGroupRepo,
+	badge_award.NewBadgeAwardRepo,
 )
