@@ -55,6 +55,8 @@ type AnswerAPIRouter struct {
 	userPluginController    *controller.UserPluginController
 	reviewController        *controller.ReviewController
 	metaController          *controller.MetaController
+	badgeController         *controller.BadgeController
+	adminBadgeController    *controller_admin.BadgeController
 }
 
 func NewAnswerAPIRouter(
@@ -86,6 +88,8 @@ func NewAnswerAPIRouter(
 	userPluginController *controller.UserPluginController,
 	reviewController *controller.ReviewController,
 	metaController *controller.MetaController,
+	badgeController *controller.BadgeController,
+	adminBadgeController *controller_admin.BadgeController,
 ) *AnswerAPIRouter {
 	return &AnswerAPIRouter{
 		langController:          langController,
@@ -116,6 +120,8 @@ func NewAnswerAPIRouter(
 		userPluginController:    userPluginController,
 		reviewController:        reviewController,
 		metaController:          metaController,
+		badgeController:         badgeController,
+		adminBadgeController:    adminBadgeController,
 	}
 }
 
@@ -159,6 +165,7 @@ func (a *AnswerAPIRouter) RegisterUnAuthAnswerAPIRouter(r *gin.RouterGroup) {
 	r.GET("/question/info", a.questionController.GetQuestion)
 	r.GET("/question/invite", a.questionController.GetQuestionInviteUserInfo)
 	r.GET("/question/page", a.questionController.QuestionPage)
+	r.GET("/question/recommend/page", a.questionController.QuestionRecommendPage)
 	r.GET("/question/similar/tag", a.questionController.SimilarQuestion)
 	r.GET("/personal/qa/top", a.questionController.UserTop)
 	r.GET("/personal/question/page", a.questionController.PersonalQuestionPage)
@@ -187,6 +194,13 @@ func (a *AnswerAPIRouter) RegisterUnAuthAnswerAPIRouter(r *gin.RouterGroup) {
 
 	// reaction
 	r.GET("/meta/reaction", a.metaController.GetReaction)
+
+	// badges
+	r.GET("/badge", a.badgeController.GetBadgeInfo)
+	r.GET("/badge/awards/page", a.badgeController.GetBadgeAwardList)
+	r.GET("/badge/user/awards/recent", a.badgeController.GetRecentBadgeAwardListByUsername)
+	r.GET("/badge/user/awards", a.badgeController.GetAllBadgeAwardListByUsername)
+	r.GET("/badges", a.badgeController.GetBadgeList)
 }
 
 func (a *AnswerAPIRouter) RegisterAuthUserWithAnyStatusAnswerAPIRouter(r *gin.RouterGroup) {
@@ -359,4 +373,8 @@ func (a *AnswerAPIRouter) RegisterAnswerAdminAPIRouter(r *gin.RouterGroup) {
 	r.PUT("/plugin/status", a.pluginController.UpdatePluginStatus)
 	r.GET("/plugin/config", a.pluginController.GetPluginConfig)
 	r.PUT("/plugin/config", a.pluginController.UpdatePluginConfig)
+
+	// badge
+	r.GET("/badges", a.adminBadgeController.GetBadgeList)
+	r.PUT("/badge/status", a.adminBadgeController.UpdateBadgeStatus)
 }
