@@ -19,6 +19,12 @@
 
 package schema
 
+import (
+	"encoding/json"
+	"github.com/apache/incubator-answer/internal/entity"
+	"sort"
+)
+
 const (
 	NotificationTypeInbox        = 1
 	NotificationTypeAchievement  = 2
@@ -95,10 +101,70 @@ type ObjectInfo struct {
 }
 
 type RedDot struct {
-	Inbox       int64 `json:"inbox"`
-	Achievement int64 `json:"achievement"`
-	Revision    int64 `json:"revision"`
-	CanRevision bool  `json:"can_revision"`
+	Inbox       int64             `json:"inbox"`
+	Achievement int64             `json:"achievement"`
+	Revision    int64             `json:"revision"`
+	CanRevision bool              `json:"can_revision"`
+	BadgeAward  *RedDotBadgeAward `json:"badge_award"`
+}
+
+type RedDotBadgeAward struct {
+	NotificationID string            `json:"notification_id"`
+	BadgeID        string            `json:"badge_id"`
+	Name           string            `json:"name"`
+	Icon           string            `json:"icon"`
+	Level          entity.BadgeLevel `json:"level"`
+}
+
+type RedDotBadgeAwardCache struct {
+	BadgeAwardList map[string]*RedDotBadgeAward `json:"badge_award_list"`
+}
+
+// NewRedDotBadgeAwardCache new red dot badge award cache
+func NewRedDotBadgeAwardCache() *RedDotBadgeAwardCache {
+	return &RedDotBadgeAwardCache{
+		BadgeAwardList: make(map[string]*RedDotBadgeAward),
+	}
+}
+
+// GetBadgeAward get badge award
+func (r *RedDotBadgeAwardCache) GetBadgeAward() *RedDotBadgeAward {
+	if len(r.BadgeAwardList) == 0 {
+		return nil
+	}
+	var ids []string
+	for _, v := range r.BadgeAwardList {
+		ids = append(ids, v.NotificationID)
+	}
+	sort.Strings(ids)
+	return r.BadgeAwardList[ids[0]]
+}
+
+// FromJSON from json
+func (r *RedDotBadgeAwardCache) FromJSON(data string) {
+	_ = json.Unmarshal([]byte(data), r)
+}
+
+// ToJSON to json
+func (r *RedDotBadgeAwardCache) ToJSON() string {
+	data, _ := json.Marshal(r)
+	return string(data)
+}
+
+// AddBadgeAward add badge award
+func (r *RedDotBadgeAwardCache) AddBadgeAward(badgeAward *RedDotBadgeAward) {
+	if r.BadgeAwardList == nil {
+		r.BadgeAwardList = make(map[string]*RedDotBadgeAward)
+	}
+	r.BadgeAwardList[badgeAward.NotificationID] = badgeAward
+}
+
+// RemoveBadgeAward remove badge award
+func (r *RedDotBadgeAwardCache) RemoveBadgeAward(notificationID string) {
+	if r.BadgeAwardList == nil {
+		return
+	}
+	delete(r.BadgeAwardList, notificationID)
 }
 
 type NotificationSearch struct {
@@ -112,8 +178,8 @@ type NotificationSearch struct {
 }
 
 type NotificationClearRequest struct {
+	NotificationType  string `validate:"required,oneof=inbox achievement" json:"type"`
 	UserID            string `json:"-"`
-	TypeStr           string `json:"type" form:"type"` // inbox achievement
 	CanReviewQuestion bool   `json:"-"`
 	CanReviewAnswer   bool   `json:"-"`
 	CanReviewTag      bool   `json:"-"`
