@@ -26,6 +26,7 @@ import (
 	"github.com/apache/incubator-answer/internal/service/activity_queue"
 	answercommon "github.com/apache/incubator-answer/internal/service/answer_common"
 	"github.com/apache/incubator-answer/internal/service/auth"
+	"github.com/apache/incubator-answer/internal/service/badge"
 	"github.com/apache/incubator-answer/internal/service/collection"
 	collectioncommon "github.com/apache/incubator-answer/internal/service/collection_common"
 	"github.com/apache/incubator-answer/internal/service/comment"
@@ -33,6 +34,7 @@ import (
 	"github.com/apache/incubator-answer/internal/service/config"
 	"github.com/apache/incubator-answer/internal/service/content"
 	"github.com/apache/incubator-answer/internal/service/dashboard"
+	"github.com/apache/incubator-answer/internal/service/event_queue"
 	"github.com/apache/incubator-answer/internal/service/export"
 	"github.com/apache/incubator-answer/internal/service/follow"
 	"github.com/apache/incubator-answer/internal/service/meta"
@@ -117,4 +119,9 @@ var ProviderSetService = wire.NewSet(
 	notice_queue.NewNewQuestionNotificationQueueService,
 	review.NewReviewService,
 	meta.NewMetaService,
+	event_queue.NewEventQueueService,
+	badge.NewBadgeService,
+	badge.NewBadgeEventService,
+	badge.NewBadgeAwardService,
+	badge.NewBadgeGroupService,
 )
