@@ -103,6 +103,10 @@ func Register(p Base) {
 		registerEmbed(p.(Embed))
 	}
 
+	if _, ok := p.(Render); ok {
+		registerRender(p.(Render))
+	}
+
 	if _, ok := p.(CDN); ok {
 		registerCDN(p.(CDN))
 	}
@@ -219,7 +223,7 @@ func MakeTranslator(key string) Translator {
 
 // Translate translates the key to the current language of the context
 func (t Translator) Translate(ctx *GinContext) string {
-	if &t == nil || t.Fn == nil {
+	if t.Fn == nil {
 		return ""
 	}
 	return t.Fn(ctx)
