@@ -92,7 +92,7 @@ const Questions: FC = () => {
           className="mt-3 mt-sm-0"
         />
       </div>
-      <Table responsive>
+      <Table responsive="md">
         <thead>
           <tr>
             <th className="min-w-15">{t('post')}</th>
@@ -110,13 +110,13 @@ const Questions: FC = () => {
             return (
               <tr key={li.id}>
                 <td>
-                  <a
-                    href={pathFactory.questionLanding(li.id, li.url_title)}
+                  <Link
+                    to={pathFactory.questionLanding(li.id, li.url_title)}
                     target="_blank"
                     className="text-break text-wrap"
                     rel="noreferrer">
                     {li.title}
-                  </a>
+                  </Link>
                   {li.accepted_answer_id > 0 && (
                     <Icon
                       name="check-circle-fill"
